# 🕹 bandai: bandits for ai

[![CI/CD](https://github.com/Arkadiy-Vladimirov/bandai/actions/workflows/ci-cd.yaml/badge.svg)](https://github.com/Arkadiy-Vladimirov/bandai/actions/workflows/ci-cd.yaml)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](LICENSE)

Lightweight multi-armed bandit implementations.
